@@ -5,9 +5,8 @@ import platform
 from e2e_cli.core.py_manager import Py_version_manager
 from e2e_cli.core.alias_service import get_user_cred
 from e2e_cli.config.config_service import is_valid
+from e2e_cli.core.constants import RESERVES
 
-# constant, reserved keywords
-RESERVES=["all", "config", "node", "bucket", "lb", "dbaas", "create", "get", "list", "update", "edit", "delete", "file"]
 
 class AuthConfig:
     def __init__(self, **kwargs):
