@@ -5,6 +5,7 @@ from e2e_cli.core.py_manager import Py_version_manager
 from e2e_cli.core.request_service import Request
 from e2e_cli.core.alias_service import get_user_cred
 from e2e_cli.core.helper_service import Checks
+from e2e_cli.core.constants import BASE_URL
 
 
 def action_table(status, req):
@@ -40,7 +41,7 @@ class nodeActions:
         
         API_key=self.API_key
         Auth_Token=self.Auth_Token
-        url = "https://api.e2enetworks.com/myaccount/api/v1/nodes/"+ node_id +"/monitor/server-health/?&apikey="+API_key
+        url =  BASE_URL+"myaccount/api/v1/nodes/"+ node_id +"/monitor/server-health/?&apikey="+API_key
         req="GET"
         status=Request(url, Auth_Token, my_payload, req).response.json()
 
@@ -58,7 +59,7 @@ class nodeActions:
         
         API_key=self.API_key
         Auth_Token=self.Auth_Token
-        url = "https://api.e2enetworks.com/myaccount/api/v1/nodes/"+ node_id +"/actions/?apikey="+API_key+"&location=Delhi"
+        url =  BASE_URL+"myaccount/api/v1/nodes/"+ node_id +"/actions/?apikey="+API_key+"&location=Delhi"
         req="POST"
         status=Request(url, Auth_Token, my_payload, req).response.json()
         
@@ -75,7 +76,7 @@ class nodeActions:
         
         API_key=self.API_key
         Auth_Token=self.Auth_Token
-        url = "https://api.e2enetworks.com/myaccount/api/v1/nodes/"+ node_id +"/actions/?apikey="+API_key+"&location=Delhi"
+        url =  BASE_URL+"myaccount/api/v1/nodes/"+ node_id +"/actions/?apikey="+API_key+"&location=Delhi"
         req="POST"
         status=Request(url, Auth_Token, my_payload, req).response.json()
         
@@ -93,7 +94,7 @@ class nodeActions:
         
         API_key=self.API_key
         Auth_Token=self.Auth_Token
-        url = "https://api.e2enetworks.com/myaccount/api/v1/nodes/"+ node_id +"/actions/?apikey="+API_key+"&location=Delhi"
+        url =  BASE_URL+"myaccount/api/v1/nodes/"+ node_id +"/actions/?apikey="+API_key+"&location=Delhi"
         req="POST"
         status=Request(url, Auth_Token, my_payload, req).response.json()
         
@@ -111,7 +112,7 @@ class nodeActions:
         
         API_key=self.API_key
         Auth_Token=self.Auth_Token
-        url = "https://api.e2enetworks.com/myaccount/api/v1/nodes/"+ node_id +"/actions/?apikey="+API_key+"&location=Delhi"
+        url =  BASE_URL+"myaccount/api/v1/nodes/"+ node_id +"/actions/?apikey="+API_key+"&location=Delhi"
         req="POST"
         status=Request(url, Auth_Token, my_payload, req).response.json()
         
@@ -129,7 +130,7 @@ class nodeActions:
         
         API_key=self.API_key
         Auth_Token=self.Auth_Token
-        url = "https://api.e2enetworks.com/myaccount/api/v1/nodes/"+ node_id +"/actions/?apikey="+API_key+"&location=Delhi"
+        url =  BASE_URL+"myaccount/api/v1/nodes/"+ node_id +"/actions/?apikey="+API_key+"&location=Delhi"
         req="POST"
         status=Request(url, Auth_Token, my_payload, req).response.json()
         
@@ -147,7 +148,7 @@ class nodeActions:
         
         API_key=self.API_key
         Auth_Token=self.Auth_Token
-        url = "https://api.e2enetworks.com/myaccount/api/v1/nodes/"+ node_id +"/actions/?apikey="+API_key+"&location=Delhi"
+        url =  BASE_URL+"myaccount/api/v1/nodes/"+ node_id +"/actions/?apikey="+API_key+"&location=Delhi"
         req="POST"
         status=Request(url, Auth_Token, my_payload, req).response.json()
         
@@ -167,7 +168,7 @@ class nodeActions:
         
         API_key=self.API_key
         Auth_Token=self.Auth_Token
-        url = "https://api.e2enetworks.com/myaccount/api/v1/nodes/"+ node_id +"/actions/?apikey="+API_key+"&location=Delhi"
+        url =  BASE_URL+"myaccount/api/v1/nodes/"+ node_id +"/actions/?apikey="+API_key+"&location=Delhi"
         req="POST"
         status=Request(url, Auth_Token, my_payload, req).response.json()
         
@@ -185,7 +186,7 @@ class nodeActions:
         
         API_key=self.API_key
         Auth_Token=self.Auth_Token
-        url = "https://api.e2enetworks.com/myaccount/api/v1/nodes/"+ node_id +"/actions/?apikey="+API_key+"&location=Delhi"
+        url =  BASE_URL+"myaccount/api/v1/nodes/"+ node_id +"/actions/?apikey="+API_key+"&location=Delhi"
         req="POST"
         status=Request(url, Auth_Token, my_payload, req).response.json()
         
@@ -203,7 +204,7 @@ class nodeActions:
         
         API_key=self.API_key
         Auth_Token=self.Auth_Token
-        url = "https://api.e2enetworks.com/myaccount/api/v1/nodes/"+ node_id +"/actions/?apikey="+API_key+"&location=Delhi"
+        url =  BASE_URL+"myaccount/api/v1/nodes/"+ node_id +"/actions/?apikey="+API_key+"&location=Delhi"
         req="POST"
         status=Request(url, Auth_Token, my_payload, req).response.json()
         
