@@ -6,6 +6,7 @@ from e2e_cli.core.py_manager import Py_version_manager
 from e2e_cli.core.alias_service import get_user_cred
 from e2e_cli.core.request_service import Request
 from e2e_cli.core.helper_service import Checks
+from e2e_cli.core.constants import BASE_URL
 from e2e_cli.node.node_crud.node_listing_service import Nodelisting
 
 
@@ -48,7 +49,7 @@ class NodeCrud:
         my_payload = payload(self.kwargs['alias'])
         API_key = self.API_key
         Auth_Token = self.Auth_Token
-        url = "https://api.e2enetworks.com/myaccount/api/v1/nodes/?apikey=" + API_key+"&location=Delhi"
+        url =  BASE_URL+"myaccount/api/v1/nodes/?apikey=" + API_key+"&location=Delhi"
         req = "POST"
         if (my_payload.Option=="auto"):
                         user_agent='cli_python'
@@ -80,7 +81,7 @@ class NodeCrud:
         node_id = Py_version_manager.py_input("please enter node id : ")
         while(not Checks.is_int(node_id)):
               node_id = Py_version_manager.py_input("please enter node id (integer only) ")
-        url = "https://api.e2enetworks.com/myaccount/api/v1/nodes/" + str(node_id) + "/?apikey="+API_key
+        url =  BASE_URL+"myaccount/api/v1/nodes/" + str(node_id) + "/?apikey="+API_key
         req = "DELETE"
 
         confirmation =Py_version_manager.py_input("are you sure you want to delete press y for yes, else any other key : ")
@@ -101,7 +102,7 @@ class NodeCrud:
         node_id = Py_version_manager.py_input("please enter node id ")
         while(not Checks.is_int(node_id)):
               node_id = Py_version_manager.py_input("please enter node id (integer only) ")
-        url = "https://api.e2enetworks.com/myaccount/api/v1/nodes/" + str(node_id) + "/?apikey="+API_key
+        url =  BASE_URL+"myaccount/api/v1/nodes/" + str(node_id) + "/?apikey="+API_key
         req = "GET"
         status = Request(url, Auth_Token, my_payload, req).response.json()
 
@@ -122,7 +123,7 @@ class NodeCrud:
         my_payload = {}
         API_key = self.API_key
         Auth_Token = self.Auth_Token
-        url = "https://api.e2enetworks.com/myaccount/api/v1/nodes/?apikey=" + API_key+"&location=Delhi"
+        url =  BASE_URL+"myaccount/api/v1/nodes/?apikey=" + API_key+"&location=Delhi"
         req = "GET"
         status = Request(url, Auth_Token, my_payload,
                        req).response.json()
